@@ -22,9 +22,9 @@ OGS model Base Class
 ^^^^^^^^^^^^^^^^^^^^
 Class to setup an ogs model
 
-.. currentmodule:: ogs5py.ogs
-
 .. autosummary::
+   :toctree: generated
+
    OGS
 
 File Classes
@@ -125,7 +125,6 @@ Information
    PCS_TYP
    PRIM_VAR_BY_PCS
 """
-from ogs5py.ogs import OGS
 from ogs5py.fileclasses import (
     ASC,
     BC,
@@ -133,11 +132,8 @@ from ogs5py.fileclasses import (
     DDC,
     FCT,
     GEM,
-    GEMinit,
     GLI,
-    GLIext,
     IC,
-    RFR,
     KRC,
     MCP,
     MFP,
@@ -150,31 +146,35 @@ from ogs5py.fileclasses import (
     PCS,
     PCT,
     PQC,
-    PQCdat,
     REI,
     RFD,
+    RFR,
     ST,
     TIM,
+    GEMinit,
+    GLIext,
+    PQCdat,
+)
+from ogs5py.ogs import OGS
+from ogs5py.tools.download import (
+    OGS5PY_CONFIG,
+    add_exe,
+    download_ogs,
+    reset_download,
 )
 from ogs5py.tools.tools import (
-    search_task_id,
     by_id,
-    hull_deform,
-    specialrange,
     generate_time,
+    hull_deform,
+    search_task_id,
+    specialrange,
 )
 from ogs5py.tools.types import OGS_EXT, PCS_TYP, PRIM_VAR_BY_PCS
-from ogs5py.tools.download import (
-    download_ogs,
-    add_exe,
-    reset_download,
-    OGS5PY_CONFIG,
-)
 from ogs5py.tools.vtk_viewer import show_vtk
 
 try:
     from ogs5py._version import __version__
-except ImportError:  # pragma: nocover
+except ModuleNotFoundError:  # pragma: nocover
     # package is not installed
     __version__ = "0.0.0.dev0"
 
