@@ -33,5 +33,5 @@ class ASC(LineFile):
     """
 
     def __init__(self, **OGS_Config):
-        super(ASC, self).__init__(**OGS_Config)
+        super().__init__(**OGS_Config)
         self.file_ext = ".asc"
