@@ -49,5 +49,5 @@ class CCT(BlockFile):
     STD = {}
 
     def __init__(self, **OGS_Config):
-        super(CCT, self).__init__(**OGS_Config)
+        super().__init__(**OGS_Config)
         self.file_ext = ".cct"
