@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 """Core module for the ogs5py GLI file."""
-from copy import deepcopy as dcp
 import os
+from copy import deepcopy as dcp
+
 import numpy as np
 
-# import ogs5py.fileclasses.gli.generator as gen
-from ogs5py.tools.types import STRTYPE, EMPTY_GLI
+from ogs5py.fileclasses.base import File
 from ogs5py.fileclasses.gli.checker import (
     check_gli_dict,
     check_polyline,
@@ -15,12 +15,14 @@ from ogs5py.fileclasses.gli.checker import (
 from ogs5py.fileclasses.gli.tools import load_ogs5gli, save_ogs5gli
 from ogs5py.tools.tools import (
     is_str_array,
+    replace,
     rotate_points,
     shift_points,
     unique_rows,
-    replace,
 )
-from ogs5py.fileclasses.base import File
+
+# import ogs5py.fileclasses.gli.generator as gen
+from ogs5py.tools.types import EMPTY_GLI, STRTYPE
 
 # current working directory
 CWD = os.getcwd()
@@ -84,7 +86,7 @@ class GLI(File):
     """
 
     def __init__(self, gli_dict=None, **OGS_Config):
-        super(GLI, self).__init__(**OGS_Config)
+        super().__init__(**OGS_Config)
         self.file_ext = ".gli"
         self.force_writing = True
 
@@ -383,7 +385,7 @@ class GLI(File):
                 self.__dict,
                 top_com=self.top_com,
                 bot_com=self.bot_com,
-                **kwargs
+                **kwargs,
             )
         else:
             print("the mesh could not be saved since it is not valid")
@@ -604,10 +606,6 @@ class GLI(File):
 
         Parameters
         ----------
-        points : ndarray
-            Array with new points. Either of shape (n,3) to add new points
-            by their coordinates or a list of points IDs refering to existing
-            points.
         name : str
             name of the new polyline
         points : ndarray
@@ -987,7 +985,7 @@ class GLIext(File):
         task_root=None,
         task_id="model",
     ):
-        super(GLIext, self).__init__(task_root, task_id)
+        super().__init__(task_root, task_id)
 
         if typ not in ["TIN", "POINT_VECTOR"]:
             raise ValueError("typ needs to be either 'TIN' or 'POINT_VECTOR'")
