@@ -74,8 +74,6 @@ def load_ogs5msh(
     The $AREA keyword within the Nodes definition is NOT supported
     and will violate the read data if present.
     """
-    # in python3 open was replaced with io.open
-    from io import open
 
     import pandas as pd
 
@@ -186,13 +184,16 @@ def load_ogs5msh(
                 filepos = msh.tell()
                 # read the elements with pandas
                 # names=range(max_node_no) to assure rectangular shape by cols
-                tmp = pd.read_csv(
-                    msh,
-                    engine="c",
+                pd_kwargs = dict(
                     delim_whitespace=True,
                     nrows=no_elements,
                     names=range(max_node_no + 4),  # +4 for the "-1" entry
-                ).values
+                )
+                try:
+                    tmp = pd.read_csv(msh, engine="c", **pd_kwargs).values
+                except pd.errors.ParserError:
+                    msh.seek(filepos)
+                    tmp = pd.read_csv(msh, engine="python", **pd_kwargs).values
                 # check if all given element-typs are OGS known
                 pos_ele = 2  # can be shift to right, if "-1" occures
                 check_elem = np.in1d(tmp[:, pos_ele], ELEM_NAMES)
@@ -301,8 +302,6 @@ def load_ogs5msh_old(filepath, verbose=True, max_node_no=8, encoding=None):
             element_id : dict
                 contains element ids for each element sorted by element types
     """
-    # in python3 open was replaced with io.open
-    from io import open
 
     import pandas as pd
 
@@ -336,13 +335,17 @@ def load_ogs5msh_old(filepath, verbose=True, max_node_no=8, encoding=None):
                 print(no_elements)
             # read the elements with pandas
             # names=range(max_node_no) to assure rectangular shape by cols
-            tmp = pd.read_csv(
-                msh,
-                engine="c",
+            filepos = msh.tell()
+            pd_kwargs = dict(
                 delim_whitespace=True,
                 nrows=no_elements,
                 names=range(max_node_no + 4),  # +4 for the "-1" entry
-            ).values
+            )
+            try:
+                tmp = pd.read_csv(msh, engine="c", **pd_kwargs).values
+            except pd.errors.ParserError:
+                msh.seek(filepos)
+                tmp = pd.read_csv(msh, engine="python", **pd_kwargs).values
             # check if all given element-typs are OGS known
             pos_ele = 2  # can be shift to right, if "-1" occures
             check_elem = np.in1d(tmp[:, pos_ele], ELEM_NAMES)
