@@ -8,12 +8,16 @@ Classes
 ^^^^^^^
 
 .. autosummary::
+   :toctree: generated
+
    Output
 
 File related
 ^^^^^^^^^^^^
 
 .. autosummary::
+   :toctree: generated
+
    search_mkey
    uncomment
    is_key
@@ -33,6 +37,8 @@ Geometric tools
 ^^^^^^^^^^^^^^^
 
 .. autosummary::
+   :toctree: generated
+
    rotate_points
    shift_points
    transform_points
@@ -45,6 +51,8 @@ Array tools
 ^^^^^^^^^^^
 
 .. autosummary::
+   :toctree: generated
+
    unique_rows
    replace
    by_id
@@ -53,19 +61,20 @@ Array tools
 
 ----
 """
+import ast
+import collections
+import glob
+import itertools
 import os
 import sys
-import glob
-import collections
-import ast
-import itertools
 from copy import deepcopy as dcp
+
 import numpy as np
 
-from ogs5py.tools.types import STRTYPE, OGS_EXT
+from ogs5py.tools.types import OGS_EXT, STRTYPE
 
 
-class Output(object):
+class Output:
     """A class to duplicate an output stream to stdout.
 
     Parameters
@@ -478,7 +487,7 @@ def specialrange(val_min, val_max, steps, typ="exp"):
             )
         ) ** typ
     else:
-        print("specialrange: unknown typ '{}'. Using linear range".format(typ))
+        print(f"specialrange: unknown typ '{typ}'. Using linear range")
         rng = np.linspace(val_min, val_max, steps)
 
     return rng
